@@ -7,15 +7,14 @@ import string
 import sys
 from typing import AnyStr, Optional
 
-from rcmt import matcher, source
+from rcmt import action, matcher, source
 from rcmt.fs import FileProxy
-from rcmt.package import action
 
 
 class Run:
     """
-    A Run connects packages with repositories. rcmt reads the Run, finds repositories
-    and packages and then applies these packages to each repository.
+    A Run connects Actions with repositories. rcmt reads the Run, finds matching
+    repositories and then applies its Actions to each repository.
 
     :param name: The name of the Run. rcmt uses the name to identify a run.
     :param auto_merge: rcmt automatically merges a pull request on its next run. The
@@ -48,8 +47,6 @@ class Run:
            run.add_matcher(FileExists("pyproject.toml"))
            run.add_matcher(RepoName("^github.com/wndhydrnt/rcmt$"))
 
-           run.add_package("flake8")
-
            run.pr_title = "A custom PR title"
            run.pr_body = '''A custom PR title.
            It supports multiline strings.'''
@@ -77,8 +74,7 @@ class Run:
 
         self.actions: list[action.Action] = []
         self.file_proxies: list[FileProxy] = []
-        self.matchers: list[matcher.Base] = []
-        self.packages: list[str] = []
+        self.matchers: list[tuple[matcher.Base, bool]] = []
 
     def __enter__(self):
         return self
@@ -94,21 +90,13 @@ class Run:
         """
         self.actions.append(a)
 
-    def add_matcher(self, m: matcher.Base) -> None:
+    def add_matcher(self, m: matcher.Base, negate: bool = False) -> None:
         """
         Add a Matcher that matches repositories.
 
         :param m: The matcher to add.
         """
-        self.matchers.append(m)
-
-    def add_package(self, name: str) -> None:
-        """
-        Add a Package to apply to every matching repository.
-
-        :param name: The name of the Package.
-        """
-        self.packages.append(name)
+        self.matchers.append((m, negate))
 
     def branch(self, prefix: str) -> str:
         if self.branch_name != "":
@@ -129,7 +117,11 @@ class Run:
 
     def match(self, repo: source.Repository) -> bool:
         for m in self.matchers:
-            if m.match(repo) is False:
+            result: bool = m[0].match(repo)
+            if m[1] is True:
+                result = not result
+
+            if result is False:
                 return False
 
         return True
